#include <stdio.h>
#include <stdlib.h>
#include <iostream.h>
#include <rawtext.h>

int main(int argc, char **argv)
{
	RawText webster("modules/texts/rawtext/websters/", "Webster", "Webster Text");
	SWListKey	listkey;

	if (argc != 2) {
		fprintf(stderr, "usage: %s <\"search string\">\n", argv[0]);
		exit(1);
	}


	for (listkey = webster.Search(argv[1]);!listkey.Error();listkey++)
		cout << (const char *)listkey << "\n";
}
